@@ -48,7 +48,7 @@ class EventsManager extends CGExtensions
 			$name = $this->Lang('friendlyname');
 		return $name;
 	}
-	function GetVersion() { return '1.2.3'; }
+	function GetVersion() { return '1.2.6'; }
 	function GetHelp() {
 		$main_help = $this->Lang('help');
 		$examples_help = $this->Lang('help_examples');
@@ -133,6 +133,8 @@ class EventsManager extends CGExtensions
 		$this->SetParameterType('sortby', CLEAN_STRING);
 		$this->SetParameterType('sortorder', CLEAN_STRING);
 		$this->SetParameterType('allow_notconnected', CLEAN_INT);
+		$this->SetParameterType('redirectdetail', CLEAN_INT);
+		$this->SetParameterType('overquotanb', CLEAN_INT);
 		
 		// Templates
 		$this->SetParameterType('summarytemplate', CLEAN_STRING);
@@ -156,6 +158,8 @@ class EventsManager extends CGExtensions
 		$this->CreateParameter('sortby', 'name', $this->Lang('param_sortby'));
 		$this->CreateParameter('sortorder', 'ASC', $this->Lang('param_sortorder'));
 		$this->CreateParameter('allow_notconnected', '0', $this->Lang('param_allow_notconnected'));
+		$this->CreateParameter('redirectdetail', '0', $this->Lang('param_redirectdetail'));
+		$this->CreateParameter('overquotanb');
 		
 		// Templates
 		$this->CreateParameter('summarytemplate', '', $this->Lang('param_summarytemplate'));
