@@ -16,6 +16,16 @@ if (isset($params['id_event']) AND ($nms_module = cms_utils::get_module('NMS')))
 	if (isset($params['submit']) AND isset($params['nms_lists']))
 	{
 		// Process the export to NMS
+
+		// Delete all the links users / nms lists
+		if (isset ($params['delete_listuser_link']))
+			foreach ($params['nms_lists'] as $onelist)
+			{
+				$db = cmsms()->GetDb();
+				$query='DELETE FROM '.NMS_LISTUSER_TABLE.' WHERE listid=?';
+				$qparams = array($onelist);
+				$res = $db->Execute($query, $qparams);
+			}
 		
 		// Retrieve the registrations
 		$registrations = $event->get_registrations();
@@ -23,9 +33,19 @@ if (isset($params['id_event']) AND ($nms_module = cms_utils::get_module('NMS')))
 		$count = 0;
 		foreach ($registrations as $registration)
 		{
-			// Verify the FEU Group
 			$continue_export = true;
-			if (isset($params['export_feu_groups']))
+			
+			// Verify if we need to sort cancelled/registered registrations
+			if (isset($params['who_export']) && ($params['who_export'] != 'all'))
+			{
+				if ( ($params['who_export'] == 'registered') && ($registration->nb_persons <= 0))
+					$continue_export=false;
+				elseif ( ($params['who_export'] == 'cancelled') && ($registration->nb_persons > 0))
+					$continue_export=false;
+			}
+			
+			// Verify the FEU Group
+			if (isset($params['export_feu_groups']) && ($continue_export))
 			{
 				// Default to false, and only if the user belongs to 1 (or more) group, we continue
 				$continue_export = false;
@@ -93,7 +113,7 @@ if (isset($params['id_event']) AND ($nms_module = cms_utils::get_module('NMS')))
 		$options[$list['name']] = $list['listid'];
 	}
 	$smarty->assign('label_nmslist', $this->CreateLabelForInput($id, 'nmslist', $this->Lang('nmslist')));
-	$smarty->assign('input_nmslist', $this->CreateInputSelectList($id, 'nms_lists[]', $options, '', 5));
+	$smarty->assign('input_nmslist', $this->CreateInputSelectList($id, 'nms_lists[]', $options, array(), 5));
 	
 	// FEU groups to export
 	// Search the FEU groups - We could use the Event groups, but if we decide to change the FEU group for an event that has registrations, we could loose some registrations for the NMS export (for the that have been allowed, and then disallowed)
@@ -101,6 +121,15 @@ if (isset($params['id_event']) AND ($nms_module = cms_utils::get_module('NMS')))
 	$event_groups = explode(',',$event->allowed_feu_groups);
 	$smarty->assign('label_export_feu_groups', $this->CreateLabelForInput($id, 'export_feu_groups', $this->Lang('export_feu_groups')));
 	$smarty->assign('input_export_feu_groups', $this->CreateInputSelectList($id, 'export_feu_groups[]', $feu_groups, $event_groups, 3));
+
+	// Who export: registered / cancelled / all ?
+	$options_list = array($this->Lang('nms_who_export_all')=>'all', $this->Lang('nms_who_export_registered')=>'registered', $this->Lang('nms_who_export_cancelled')=>'cancelled');
+	$smarty->assign('label_who_export', $this->CreateLabelForInput($id, 'who_export', $this->Lang('nms_who_export')));
+	$smarty->assign('input_who_export', $this->CreateInputDropdown($id, 'who_export', $options_list, 0));
+
+	// Delete all users from the target NMS list
+	$smarty->assign('label_delete_listuser_link', $this->CreateLabelForInput($id, 'delete_listuser_link', $this->Lang('delete_listuser_link_label')));
+	$smarty->assign('input_delete_listuser_link', $this->CreateInputCheckbox($id, 'delete_listuser_link', '1', 0, 'id="'.$id.'delete_listuser_link"'));
 	
 	// Event object
 	$smarty->assign('event', $event->get_smarty_object());
