@@ -16,6 +16,8 @@ $lang['draft'] = 'Brouillon';
 $lang['events'] = 'Evénements';
 $lang['preferences'] = 'Préférences';
 $lang['categories'] = 'Catégories';
+$lang['fielddefs'] = 'Champs extra';
+$lang['mails'] = 'E-Mails';
 
 $lang['edit'] = 'Editer';
 $lang['delete'] = 'Supprimer';
@@ -55,6 +57,7 @@ $lang['regdate'] = 'Date d\'inscription';
 $lang['export_regusers'] = 'Exporter les inscriptions';
 $lang['export_regusers_file'] = 'Vers CSV';
 $lang['exportencoding'] = 'Encodage des fichiers CSV exportés';
+$lang['no_registrations'] = 'Il n\'y a aucune inscription pour cet évènement';
 
 # NMS Export
 $lang['export_regusers_nms'] = 'Exporter vers une liste Newsletter Made Simple ';
@@ -74,6 +77,25 @@ $lang['category'] = 'Catégorie';
 $lang['addcategory'] = "Ajouter une catégorie d'événements";
 $lang['editcategory'] = "Modifier une catégorie d'événements";
 
+# E-Mails # General
+$lang['mail_sendtouser_label'] = "Envoyer un e-mail à l'utilisateur qui s'inscrit (note : ceci ne fonctionne que si l'utilisateur FEU dispose d'un e-mail dans son compte)";
+$lang['mail_sendtoother_label'] = "Envoyer un e-mail à ces adresses (liste séparée par des virgules) ";
+$lang['mail_template_help'] = 'Objets disponibles :<br />
+<strong>{$event}</strong> : infos sur l\'évènement ($event->name, $event->description, $event->extrafieldsbyname.mon-champ->value, etc.)<br />
+<strong>{$registration}</strong> : informations sur l\'inscription ($registration->nb_persons)<br />
+<strong>{$feu_user}</strong> : l\'utilisateur FEU';
+$lang['mail_subject'] = "Sujet de l'e-mail";
+
+#E-Mails # New registration
+$lang['mail_newregistration_title'] = "E-mail envoyé lors d'une nouvelle inscription";
+$lang['email_to_who_newregistration'] = "Qui doit recevoir un e-mail lors d'une nouvelle inscription ?";
+$lang['mail_newregistration_template'] = "Gabarit du mail envoyé lors d'une nouvelle inscription";
+
+# E-mails # Cancel registration
+$lang['mail_cancelregistration_title'] = "E-mail envoyé lors d'une annulation d'inscription";
+$lang['email_to_who_cancelregistration'] = "Qui doit recevoir un e-mail lors d'une annulation d'inscription ?";
+$lang['mail_cancelregistration_template'] = "Gabarit du mail envoyé lors d'une annulation d'inscription";
+
 # Errors
 $lang['error_emptyname'] = "Vous n'avez pas saisi de nom";
 $lang['error_nameused'] = 'Une catégorie portant ce nom existe déjà';
@@ -101,13 +123,13 @@ $lang['eventregistrationoptions'] = "Préférences de l'inscription aux événem
 $lang['label_dflt_registrationpage'] = "Page par défaut sur laquelle afficher le formulaire d'inscription. Si 'Aucun' est sélectionné, c'est la page courante qui sera utilisée";
 
 $lang['reguserslistoptions'] = 'Préférences de la liste des inscrits à un événement';
-$lang['displayed_feu_properties'] = 'Propriétés FEU affichées dans la liste des inscriptions et à l\'export';
+$lang['displayed_feu_properties'] = "Propriétés FEU affichées dans la liste des inscriptions et à l'export";
 
 # Templates / Admin
 $lang['summarytemplates'] = 'Gabarits de sommaire';
 $lang['detailtemplates'] = 'Gabarits de détail';
 $lang['registrationtemplates'] = "Gabarits d'inscription";
-$lang['registrationslisttemplates'] = "Gabarits de listes d'inscrits'";
+$lang['registrationslisttemplates'] = "Gabarits de listes d'inscrits";
 
 $lang['summarytemplate_addedit'] = "Ajouter / Editer un gabarit de sommaire des événements ";
 $lang['detailtemplate_addedit'] = "Ajouter / Editer un gabarit de détail d'un événement ";
@@ -120,6 +142,7 @@ $lang['param_action'] = "Définit le comportement du module. Les valeurs possibl
 	<li><em>default</em> - Affiche la liste des évènements - Vous pouvez aussi utiliser : <em>action='summary'</em></li>
 	<li>detail - Affiche le détail d'un évènement - Utilisez le paramètre 'event_id' pour spécifier l'évènement à afficher</li>
 	<li>register - Affiche le formulaire d'inscription à un évènement - Utilisez le paramètre event_id pour préciser l'évènement auquel s'inscrire</li>
+	<li>registrationslist - Affiche la liste des inscriptions à un évènement - Utilisez le paramètre event_id pour préciser l'évènement concerné (voir l'aide plus haut)</li>
 </ul>
 ";
 $lang['param_event_id'] = "Utilisé uniquement avec les actions <em>detail</em>, <em>register</em> et <em>registrationslist</em> - ID de l'événement auquel rattacher l'action";
@@ -136,7 +159,8 @@ $lang['param_status'] = "Utilisé uniquement avec l'action <em>default</em>, n'a
 $lang['param_show'] = "Utilisé uniquement avec l'action <em>default</em>, affiche les évènements selon un critère de date.
 <br />Valeurs possibles :
 <ul>
-	<li>upcoming : évènements en cours et à venir - paramètre par défaut</li>
+	<li>all : tous les évènements (passés, en cours, à venir) - paramètre par défaut</li>
+	<li>upcoming : évènements en cours et à venir</li>
 	<li>past : évènements passés</li>
 	<li>currently : évènements en cours (date de début < date actuelle < date de fin)</li>
 	<li>custom : vous permet de spécifier une date/heure de début et de fin - Voir les paramètres start_datetime et end_datetime</li>
@@ -185,6 +209,15 @@ $lang['help'] = "
 <p>Utilisez simplement l'action <strong>registrationslist</strong> de cette manière : <strong>{EventsManager action='registrationslist' event_id=5}</strong> où <strong>id_event</strong> correspond à l'id de l'évènement pour lequel afficher les inscrits</p>
 <p>Pour personnaliser d'avantage votre liste d'évènements, consultez la liste des options disponibles en bas de cette page. Vous pouvez aussi personnaliser vos gabarits d'affichage grâce à Smarty.</p>
 
+<h3>Sponsors</h3>
+<p>Le développement de ce module a été sponsorisé par :
+	<ul>
+		<li>Alternative DG : <a href='www.alternativedg.com'>www.alternativedg.com</a></li>
+		<li>TO : <a href='www.t-o.be'>www.t-o.be</a></li>
+	</ul>
+</p>
+<p>Merci beaucoup à ces entreprises ! Si vous souhaitez sponsoriser le développement d'une fonction, envoyez-moi un e-mail : <a href='mailto:contact@airelibre.fr'>contact@airelibre.fr</a></p>
+
 <h3>Assistance</h3>
 <p>Ce module est fourni sans aucune assistance commerciale. Cependant,
 vous pouvez tout de même obtenir de l'aide :</p>
