@@ -23,7 +23,11 @@ $flds = "
 	price F,
 	capacity_per_feu I,
 	create_datetime " . CMS_ADODB_DT . ",
-	modify_datetime " .CMS_ADODB_DT;
+	modify_datetime " .CMS_ADODB_DT . ",
+	limited_reg_period I1 DEFAULT '0', 
+	reg_start_datetime ".CMS_ADODB_DT . ",
+	reg_end_datetime ".CMS_ADODB_DT . ",
+	cancelled I";
 $sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_events", $flds, $taboptarray);
 $dict->ExecuteSQLArray($sqlarray);
 
@@ -89,6 +93,20 @@ if( file_exists( $fn ) )
 	$this->SetPreference('dflt_registrationslist_template','Sample');
 }
 
+# Mails templates
+$fn = cms_join_path(dirname(__FILE__),'templates','orig_newregistrationmailtemplate.tpl');
+if( file_exists( $fn ) )
+{
+	$template = file_get_contents( $fn );
+	$this->SetTemplate('newregistrationmail_Sample',$template);
+}
+$fn = cms_join_path(dirname(__FILE__),'templates','orig_cancelregistrationmailtemplate.tpl');
+if( file_exists( $fn ) )
+{
+	$template = file_get_contents( $fn );
+	$this->SetTemplate('cancelregistrationmail_Sample',$template);
+}
+
 // Permissions
 $this->CreatePermission('Use EventsManager', 'Use EventsManager');
 
@@ -96,6 +114,27 @@ $this->CreatePermission('Use EventsManager', 'Use EventsManager');
 $this->SetPreference('menuname', '');
 $this->SetPreference('dflt_detailpage', '-1');
 $this->SetPreference('dflt_registrationpage', '-1');
+$this->SetPreference('dflt_feuloginpage', '-1');
+
+$this->SetPreference('newregistration_mail_sendtouser', 0);
+$this->SetPreference('newregistration_mail_sendtoother', 0);
+$this->SetPreference('newregistration_mail_sendtoother_mails', '');
+
+$this->SetPreference('cancelregistration_mail_sendtouser', 0);
+$this->SetPreference('cancelregistration_mail_sendtoother', 0);
+$this->SetPreference('cancelregistration_mail_sendtoother_mails', '');
+
+// Mail subjects
+$this->SetPreference('newregistration_mail_subject', 'New registration to the event {$event->name}');
+$this->SetPreference('cancelregistration_mail_subject', 'Registration cancelled for the event {$event->name}');
+
+// Some other prefs
+// By default, do the registration when a user enters an over-quota number of registrations
+$this->SetPreference('overquota_behaviour', 'reg_with_limit');
+// Export cancelled users in CSV
+$this->SetPreference('export_cancelled', 1);
+// Show tabs in event edit window
+$this->SetPreference('showtabs', 1);
 
 // CMSMS Events
 $this->CreateEvent('EventsManagerEventAdded');
@@ -109,4 +148,7 @@ $this->CreateEvent('EventsManagerCategoryDeleted');
 $this->CreateEvent('EventsManagerRegistrationAdded');
 $this->CreateEvent('EventsManagerRegistrationEdited');
 
+// Handle the registration after FEU login
+$this->AddEventHandler('FrontEndUsers', 'OnLogin', true);
+
 ?>
\ No newline at end of file
